local RC = LibStub("AceAddon-3.0"):GetAddon("Raid Check")
local L = LibStub("AceLocale-3.0"):GetLocale("Raid Check", true)

-- Player Data Array is currently composed of: Name, Realm, hasFlask, hasFood, hasRune, Class, Role, hasVantusRune
RC.playerData = {};

RC.AddOn_Name = "Raid Check";

RC.MainFrameWidth = 325;

RC.GrpWidth = RC.MainFrameWidth-5;
RC.DDWidth = 100;

RC.ButtonWidth = 85;
RC.ButtonHeight = 25;

RC.PlayerWidth	= 115;
RC.FlFoRuWidth	= 40;
RC.SpellWidth	= 80;
RC.Spacing = 5;

-- UI Height Slider Variables
RC.UserScreenResolution = ({GetScreenResolutions()})[GetCurrentResolution()];
if RC.UserScreenResolution then
	RC.MaxWidth, RC.MaxHeight = RC.UserScreenResolution:match("([^,]+)x([^,]+)")
else
	RC.MaxWidth = 325
	RC.MaxHeight = 800
end
RC.MinHeight = 240;
RC.SliderStep = 10;

RC.GBoW = 203539; -- Retribution Paladin's Greater Blessing of Wisdom

-- Food Levels will change after hitting 60 on live, will remove BFA at SL launch
RC.FoodLevels = {
	30,
	19,
	18,
	15,
	14,
};

RC.Food = {
	327706, -- SL Strength 20
	327707, -- SL Stamina 30 (20)
	327708, -- SL Intellect 20
	327709, -- SL Agility 20

	327701, -- SL Strength 18
	327702, -- SL Stamina 27 (18)
	327704, -- SL Intellect 18
	327705, -- SL Agility 18

	308525, -- SL Stam 22
	308520, -- SL Stam 14

	308434, -- SL Crit 30
	308488, -- SL Haste 30
	308506, -- SL Mastery 30
	308514, -- SL Versatility 30

	308430, -- SL Crit 18
	308474, -- SL Haste 18
	308504, -- SL Mastery 18
	308509, -- SL Versatility 18

	297116, -- BFA Agility 19
	297117, -- BFA Intellect 19
	297118, -- BFA Strength 19
	297119, -- BFA Stamina 29 (19)

	259454,	-- BfA Agility 15
	259455,	-- BfA Intellect 15
	259456,	-- BfA Strength 15
	259457,	-- BfA Stamina 22 (15)

	297034, -- BFA Haste 14
	297035, -- BFA Mastery 14
	297037, -- BFA Versatility 14
	297039, -- BFA Crit 14

	290469, -- BfA Strength 13
	290468, -- BfA Intellect 13
	290467, -- BfA Agility 13

	288075, -- BfA Stamina 22
	288074, -- BfA Stamina 17
	297040, -- BFA Stam 29
};

RC.FlaskLevels = {
	105, -- SL Flask of Power
	38,	-- BfA Flasks
};

RC.Flask = {
	307185, --SL Spectral Flask of Power (Agility Intellect Strength)
	307187, --SL Spectral Flask of Stamina

	298836, --BFA Agility
	298837, --BFA Intellect
	298839, --BFA Stamina
	298841, --BFA Strength
};

RC.RuneLevels = {
	60, --Veiled Augment Rune
	6, --BfA Rune
};

RC.Runes = {
	317065, --Lightning rune
	270058,	--Battle-Scarred Augmentation
};

RC.FelFocus = 242551; --Fel Focus 7.2

--Vantus Rune Checking
RC.VantusRuneCheckEnabled = false  -- Global variable to assist in checking for Vantus Rune buffs only when we are at the selected Boss

--These are set as sub tables because when we check for a Spell we are using a table, in this way we only need to provide the selected SpellID that corresponds to the selected Vantus Rune to check
RC.VantusSpellIds = {
	{0},
	{313556}, -- N/Zoth
	{311445}, -- Shriekwing
	{334132}, -- Altimor the Huntsman
	{311446}, -- Hungering Destroyer
	{311447}, -- Artificer Xy'Mox
	{311448}, -- Sun King's Salvation
	{311449}, -- Lady Inerva Darkvein
	{311450}, -- The Council of Blood
	{311451}, -- Sludgefist
	{311452}, -- Stoneborne Generals
	{334131}, -- Sire Denathrius
};

--Since some of the fights are Council fights, then we need to utilize sub-tables for consistency, it also appears that there are multiple IDs?
RC.VantusBossIds = {
	{0},
	{158041}, -- N'Zoth
	{172145}, -- Shriekwing
	{165066}, -- Altimor the Huntsman
	{164261}, -- Hungering Destroyer
	{166644}, -- Artificer Xy'Mox
	{165759}, -- Sun King's Salvation
	{167517}, -- Lady Inerva Darkvein
	{166971,166970,166969}, -- The Council of Blood
	{174733}, -- Sludgefist
	{165318,175233}, -- Stoneborne Generals
	{168938}, -- Sire Denathrius
};

-- In Game if you run the following, it gives you the list of all Encounter IDs, we are going to use this to find the proper IDs to populate the Encounter Names.
-- The script is from WowInterface user Ketho:  http://www.wowinterface.com/forums/showthread.php?t=53806
-- /run local i=1 while EJ_GetInstanceByIndex(i,true)do local a1,a2=EJ_GetInstanceByIndex(i,true)print(a1,a2)EJ_SelectInstance(a1)i=i+1 local j=1 while EJ_GetEncounterInfoByIndex(j,a1)do local b1,_,b2=EJ_GetEncounterInfoByIndex(j,a1)print(b2,b1)j=j+1 end end
RC.EncounterIds = {
	2375, --N'Zoth
	2393, -- Shriekwing
	2429, -- Altimor the Huntsman
	2428, -- Hungering Destroyer
	2418, -- Artificer Xy'Mox
	2422, -- Sun King's Salvation
	2420, -- Lady Inerva Darkvein
	2426, -- The Council of Blood
	2394, -- Sludgefist
	2425, -- Stoneborne Generals
	2424, -- Sire Denathrius
};

--We want this to be a localized list, so we populate all the Boss Names when the Settings tab is opened, we use the Encounter IDs
RC.VantusBossNames = {
	L["none"],
};


--The following are override values for items that may not give the exact number appropriately
--[[RC.OverRide17 = 225606; -- Fishbrul Special (17)

RC.OverRide75 = {
	201637, -- Feast Stamina 27 (18)
	201636, -- Feast Intellect 18
	201635, -- Feast Agility 18
	201634, -- Feast Strength 18

};

RC.OverRide100 = {
	201641, -- Feast Stamina 34 (22)
	201640, -- Feast Intellect 22
	201639, -- Feast Agility 22
	201638, -- Feast Strength 22
};--]]


-- These are the primary stat buffs, we will also use these to create labels in the UI to include the Name used as I think the name retruned from GetSpellInfo is localized
-- If I set these to true, then as I'm going through the group if anyone doesn't have it then I can set it to false it will only be green if everyone in the group has the buff
RC.PrimaryStatBuffs = {
	{1459, true},	--Arcane Intellect
	{6673, true},	--Battle Shout
	{21562, true},	--Power Word Fortitude
};

-- Currently anything more complex than this is kind of pointless
-- 1:Warrior	2:Paladin	3:Hunter	4:Rogue	5:Priest	6:Death Knight	7:Shaman	8:Mage	9:Warlock	10:Monk	11:Druid	12:Demon Hunter
RC.ClassInGroup = {};
for i = 1, GetNumClasses() do
	RC.ClassInGroup[i] = false;
end

RC.Warriors	= "";
RC.Paladins	= "";
RC.Hunters	= "";
RC.Priests	= "";
RC.DKs		= "";
RC.Shamans	= "";
RC.Mages	= "";
RC.Warlocks	= "";
RC.Monks	= "";
RC.Druids	= "";
RC.DHs		= "";
